VooContextSwitcherCardData class

Data passed to custom card builder.

This class provides all the information needed to build a custom card for the context switcher's closed state.

Constructors

VooContextSwitcherCardData({VooContextItem? selectedItem, required bool isExpanded, required VoidCallback onTap, String? placeholder})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isExpanded bool
Whether the modal is currently expanded
final
onTap VoidCallback
Callback to toggle the modal open/closed
final
placeholder String?
Placeholder text when no context is selected
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedItem VooContextItem?
Currently selected context
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited